# This file was generated by Nuitka

# Stubs included by default


class ParameterError(Exception): ...
class ArgumentError(Exception): ...
class InstanceError(Exception): ...
class ParseError(Exception): ...
class ExistsError(Exception): ...
__name__ = ...



# No other modules used internally, no implicit dependencies.
